==> blesta-5.10.2.zip: blesta/plugins/download_manager/language/de_de/download_manager_files.php <==
<?php
/**
 * Download Manager Files
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DownloadManagerFiles.!error.file_id.exists'] = 'Die zu aktualisierende Datei existiert nicht.';
$lang['DownloadManagerFiles.!error.file_packages.format'] = 'Mindestens ein ausgewähltes Paket kann nicht hinzugefügt werden, da es nicht existiert.';
$lang['DownloadManagerFiles.!error.permit_packages.format'] = 'Die Paketverfügbarkeitsoption hat ein ungültiges Format.';
$lang['DownloadManagerFiles.!error.file_groups.format'] = 'Mindestens eine ausgewählte Kundengruppe kann nicht hinzugefügt werden, da sie nicht existiert.';
$lang['DownloadManagerFiles.!error.permit_client_groups.format'] = 'Die Option für die Verfügbarkeit der Kundengruppe hat ein ungültiges Format.';
$lang['DownloadManagerFiles.!error.public.assignment'] = 'Die Datei muss entweder für die Öffentlichkeit, Kundengruppen oder Pakete verfügbar sein.';
$lang['DownloadManagerFiles.!error.public.format'] = 'Die Option der öffentlichen Verfügbarkeit hat ein ungültiges Format.';
$lang['DownloadManagerFiles.!error.file_name.format'] = 'Bitte laden Sie eine Datei hoch oder geben Sie einen gültigen Pfad zur Datei an.';
$lang['DownloadManagerFiles.!error.name.empty'] = 'Bitte geben Sie einen Namen für diese Datei ein.';
$lang['DownloadManagerFiles.!error.company_id.exists'] = 'Ungültige Unternehmens-ID.';
$lang['DownloadManagerFiles.!error.category_id.exists'] = 'Bitte wählen Sie eine gültige Kategorie.';

==> blesta-5.11.4.zip: blesta/plugins/download_manager/language/de_de/download_manager_files.php <==
<?php
/**
 * Download Manager Files
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DownloadManagerFiles.!error.file_id.exists'] = 'Die zu aktualisierende Datei existiert nicht.';
$lang['DownloadManagerFiles.!error.file_packages.format'] = 'Mindestens ein ausgewähltes Paket kann nicht hinzugefügt werden, da es nicht existiert.';
$lang['DownloadManagerFiles.!error.permit_packages.format'] = 'Die Paketverfügbarkeitsoption hat ein ungültiges Format.';
$lang['DownloadManagerFiles.!error.file_groups.format'] = 'Mindestens eine ausgewählte Kundengruppe kann nicht hinzugefügt werden, da sie nicht existiert.';
$lang['DownloadManagerFiles.!error.permit_client_groups.format'] = 'Die Option für die Verfügbarkeit der Kundengruppe hat ein ungültiges Format.';
$lang['DownloadManagerFiles.!error.public.assignment'] = 'Die Datei muss entweder für die Öffentlichkeit, Kundengruppen oder Pakete verfügbar sein.';
$lang['DownloadManagerFiles.!error.public.format'] = 'Die Option der öffentlichen Verfügbarkeit hat ein ungültiges Format.';
$lang['DownloadManagerFiles.!error.file_name.format'] = 'Bitte laden Sie eine Datei hoch oder geben Sie einen gültigen Pfad zu der Datei im Uploads-Verzeichnis an.';
$lang['DownloadManagerFiles.!error.name.empty'] = 'Bitte geben Sie einen Namen für diese Datei ein.';
$lang['DownloadManagerFiles.!error.company_id.exists'] = 'Ungültige Unternehmens-ID.';
$lang['DownloadManagerFiles.!error.category_id.exists'] = 'Bitte wählen Sie eine gültige Kategorie.';
